@@ -18,8 +18,8 @@ $EM_CONF[$_EXTKEY] = [
             'SG\\SgSitepackage\\' => 'Classes'
         ],
     ],
-    'state' => 'beta',
-    'version' => '10.1.0',
+    'state' => 'stable',
+    'version' => '10.8.0',
     'author' => 'Daniel Hoffmann, Marc Saleiko',
     'author_email' => 'hoffmann@smply.gd, saleiko@smply.gd',
     'author_company' => 'Smply.gd GmbH',
